@@ -136,8 +136,10 @@ class SendGrid(object):
 
     def edit_newsletter(self, **fields):
         '''fields must be name, newname, subject, text, html'''
-        identity = self.list_identity()['response'][0]['identity']
-        return self.call('newsletter', 'edit', dict(identity=identity, **fields))
+        identity = fields.pop('identity', None)
+        if identity is None:
+            identity = self.list_identity()['response'][0]['identity']
+        return self.call('newsletter', 'edit', dict(**fields))
 
     def list_identity(self, name=None):
         return self.call('identity', 'list', {"name": name} if name else {})
